summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2021-06-30 13:41:37 (GMT)
committerBrad King <brad.king@kitware.com>2021-06-30 14:13:56 (GMT)
commit83a3db56317bf0ef3b41c4fc437a6a31d36c8b73 (patch)
tree277c43d46727bc8a0f64e62420d6615684ffedc4
parentd76cb12905df6d76fe3ee5376913e5d61161f71d (diff)
downloadCMake-83a3db56317bf0ef3b41c4fc437a6a31d36c8b73.zip
CMake-83a3db56317bf0ef3b41c4fc437a6a31d36c8b73.tar.gz
CMake-83a3db56317bf0ef3b41c4fc437a6a31d36c8b73.tar.bz2
export: Increase maximum policy version in exported files to 3.20
The files generatd by `install(EXPORT)` and `export()` commands are known to work with policies as of CMake 3.20, so enable them in sufficiently new CMake versions.
-rw-r--r--Source/cmExportFileGenerator.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/cmExportFileGenerator.cxx b/Source/cmExportFileGenerator.cxx
index dd611de..c69d484 100644
--- a/Source/cmExportFileGenerator.cxx
+++ b/Source/cmExportFileGenerator.cxx
@@ -924,13 +924,13 @@ void cmExportFileGenerator::GeneratePolicyHeaderCode(std::ostream& os)
// Isolate the file policy level.
// Support CMake versions as far back as 2.6 but also support using NEW
// policy settings for up to CMake 3.19 (this upper limit may be reviewed
// and increased from time to time). This reduces the opportunity for CMake
// warnings when an older export file is later used with newer CMake
// versions.
/* clang-format off */
os << "cmake_policy(PUSH)\n"
- << "cmake_policy(VERSION 2.6...3.19)\n";
+ << "cmake_policy(VERSION 2.6...3.20)\n";
/* clang-format on */
}
@@ -924,13 +924,13 @@ void cmExportFileGenerator::GeneratePolicyHeaderCode(std::ostream& os)
// Isolate the file policy level.
// Support CMake versions as far back as 2.6 but also support using NEW
- // policy settings for up to CMake 3.19 (this upper limit may be reviewed
+ // policy settings for up to CMake 3.20 (this upper limit may be reviewed
// and increased from time to time). This reduces the opportunity for CMake
// warnings when an older export file is later used with newer CMake